import argparse
import eaiConstants


class Arguments(object):
    def __init__(self):
        self.parser = argparse.ArgumentParser(description="eggplant AI Agent")

        # Eggplant AI server address
        self.parser.add_argument(
            "-s",
            "--server",
            type=str,
            default=eaiConstants.DEFAULT_SERVER,
            help='The Eggplant AI server e.g. "server.mycompany.com". '
            "Default={0}".format(eaiConstants.DEFAULT_SERVER),
        )

        # Eggplant Functional drive port
        self.parser.add_argument(
            "-p",
            "--port",
            type=int,
            default=eaiConstants.DEFAULT_EGGDRIVE_PORT,
            help="The port to run Eggplant Functional drive on "
            "default={0}".format(str(eaiConstants.DEFAULT_EGGDRIVE_PORT)),
        )

        # Path to Eggplant Functional drive executable
        self.parser.add_argument(
            "-e",
            "--driveExec",
            type=str,
            default=eaiConstants.DEFAULT_EGGDRIVE_EXECUTABLE,
            help="The location of the Eggplant Functional drive "
            "executable default={0}".format(eaiConstants.DEFAULT_EGGDRIVE_EXECUTABLE),
        )

        # Execution environment (connection) name
        self.parser.add_argument(
            "-n",
            "--name",
            type=str,
            default="",
            help="A name for the agent connection to be used in "
            "Eggplant AI settings. If unspecified an ip address "
            "will be used",
        )

        # Whether to use SSL connection
        self.parser.add_argument(
            "--ssl",
            dest="ssl",
            action="store_true",
            help="use ssl connection to server (Default)",
        )
        self.parser.add_argument(
            "--no-ssl",
            dest="ssl",
            action="store_false",
            help="do not use ssl connection to server",
        )
        self.parser.set_defaults(ssl=True)

        # Whether to start the Eggplant Functional GUI
        self.parser.add_argument(
            "--epfgui",
            dest="epfgui",
            action="store_true",
            help="start the Eggplant Functional GUI",
        )
        self.parser.add_argument(
            "--no-epfgui",
            dest="epfgui",
            action="store_false",
            help="do not start the Eggplant Functional GUI (Default)",
        )
        self.parser.set_defaults(epfgui=True)

        # Debug mode
        self.parser.add_argument(
            "--debug",
            dest="debug",
            action="store_true",
            help="run the agent in debug mode (more messaging)",
        )
        self.parser.set_defaults(debug=False)

        # Whether to clean up remaining Eggplant Functional processes before starting
        self.parser.add_argument(
            "--clean-epf",
            dest="cleanepf",
            action="store_true",
            help="kill any straggling Eggplant Functional processes "
            "before starting new",
        )
        self.parser.set_defaults(cleanepf=False)

        # Whether to start Eggplant Functional drive, or use an already-running instance
        self.parser.add_argument(
            "--no-start-epf",
            dest="startepf",
            action="store_false",
            help="do not start Eggplant Functional, expect it to already be running on "
            "specified port",
        )
        self.parser.set_defaults(startepf=True)

        # Run in DESIGN or RUN mode (affects execution environment availability)
        self.parser.add_argument(
            "--design-mode",
            dest="designMode",
            action="store_true",
            help="connect to the server as a Design execution environment",
        )

        # Eggplant Functional suite root folder path
        self.parser.add_argument(
            "--suite-root-folder",
            dest="suiteRootFolder",
            type=str,
            default="",
            help="The full path to a folder. Eggplant Functional suites will be "
            "uploaded and downloaded as sub-folders of the specified root folder.",
        )

        # Server auth token
        self.parser.add_argument(
            "--token",
            dest="token",
            type=str,
            help="The token to use to authenticate against the server",
        )

        self.parser.add_argument(
            "--retry-auth",
            dest="retryAuth",
            action="store_true",
            help="Retry authentication indefinitely",
        )

    def parse_args(self):
        # This returns a Namespace object, as per
        # https://docs.python.org/3/library/argparse.html#argparse.Namespace
        return self.parser.parse_args()
