import logging
import sys
import time
import os

from version import versionOrBuild, eggPlantAIAgentBuild
from top import Top
from ArgumentsParser import Arguments
from asset_controller import AssetController
from asset_manager_factory import create_asset_manager
from token_verifier import verify_token, verify_permissions, TokenValidationException
from logger import setup_logging


if __name__ == "__main__":
    arguments = Arguments()
    args = arguments.parse_args()

    if args.debug:
        log_level = logging.getLevelName(logging.DEBUG)
    else:
        log_level = os.environ.get(
            "AGENT_LOG_LEVEL", logging.getLevelName(logging.INFO)
        )

    setup_logging(
        log_level,
        (
            "%(asctime)s [%(threadName)-12.12s]"
            "[%(levelname)-5.5s][%(name)s] %(pathname)s %(message)s"
        ),
    )

    logging.info(
        "Running Eggplant AI agent version {}, build {}".format(
            versionOrBuild(), eggPlantAIAgentBuild
        )
    )
    logging.info(
        "Arguments server={0} name={1} port={2}, ssl={3} "
        "epfgui={4} driveExec={5} clean epf={6} start epf={7} "
        "designMode={8} suiteRootFolder={9} token={10} retryAuth={11}".format(
            args.server,
            args.name,
            args.port,
            args.ssl,
            args.epfgui,
            args.driveExec,
            args.cleanepf,
            args.startepf,
            args.designMode,
            args.suiteRootFolder,
            args.token,
            args.retryAuth,
        )
    )

    # Check that the runscript file exists at the set (or default) location
    if not os.path.isfile(args.driveExec):
        logging.error(
            "The Eggplant Functional drive executable "
            'was not found at "{0}"'.format(args.driveExec)
        )
        sys.exit(1)

    # Verify the token is valid
    token_verified = False

    while not token_verified:
        try:
            verify_token(args.server, args.ssl, args.token)
            token_verified = True
        except TokenValidationException as e:
            logging.error(str(e))

            if not args.retryAuth:
                sys.exit(1)

            time.sleep(10)
            logging.info("Retrying authorization")

    try:
        verify_permissions(args.token, args.designMode)
    except TokenValidationException as e:
        logging.error(str(e))
        sys.exit(1)

    asset_manager = create_asset_manager(args.server, args.ssl, args.token)
    asset_controller = AssetController(asset_manager)
    t = Top(args, asset_controller)
    t.run()  # run the websocket interface
