import logging
from threading import Thread
from queue import Queue, Empty


def run_background_job(widget, callback, fn, *args, **kwargs):

    background_job = BackgroundJob(fn)

    def check_progress():
        try:
            result = background_job.get_result()
            if result is None:
                widget.after(100, check_progress)
            else:
                callback(result, None)
        except Exception as e:
            logging.error("Background job failed: %s", str(e))
            callback(None, e)

    widget.after(100, check_progress)
    background_job.start(*args, **kwargs)


class BackgroundJob(object):
    def __init__(self, fn):
        self.fn = fn
        self.queue = Queue()

    def start(self, *args, **kwargs):
        thread = Thread(target=self.run, args=args, kwargs=kwargs)
        thread.daemon = True
        thread.start()

    def run(self, *args, **kwargs):
        try:
            result = self.fn(*args, **kwargs)
            self.queue.put_nowait((True, result))
        except Exception as e:
            self.queue.put_nowait((False, e))

    def get_result(self):
        try:
            success, result = self.queue.get_nowait()
            if success:
                return result
            else:
                raise result
        except Empty:
            return None
