import datetime
import logging
import logging.handlers
import os

import appdirs


def setup_logging(level, format, log_queue=None):
    log_file = os.environ.get(
        "AGENT_LOG_FILE",
        os.path.join(
            appdirs.user_log_dir("agent", "eggplant"),
            "log_{}.txt".format(datetime.datetime.now().strftime("%Y%m%d_%H%M%S")),
        ),
    )

    os.makedirs(os.path.dirname(log_file), exist_ok=True)

    handlers = [
        logging.StreamHandler(),
        logging.FileHandler(log_file, encoding="utf-8"),
    ]

    if log_queue is not None:
        handlers.append(logging.handlers.QueueHandler(log_queue))

    logging.basicConfig(
        level=logging.getLevelName(level), format=format, handlers=handlers,
    )
