import re
import logging


def extract_ip_address_from_server_string(server_string):
    try:
        if server_string == "":
            return None
        else:
            return server_string.split(":")[0]
    except Exception:
        logging.warning(
            "unable to extract ip address from server string, \
            setting ip address to None instead"
        )
        return None


def extract_port_from_server_string(server_string):
    try:
        port_to_return = server_string.split(":")[1]
        if is_server_port_valid(port_to_return):
            return port_to_return
        else:
            return None
    except Exception:
        logging.warning(
            "unable to extract port from server string, \
            setting port to None instead"
        )
        return None


def is_server_port_valid(port):
    if (port is not None) and (port != ""):
        return re.match("^[0-9]*$", port) is not None
    else:
        return False


def construct_server_address_string(ip_address, port):
    return "{}:{}".format(ip_address, port)
