from datetime import timezone


class Suite(object):
    MISSING_FROM_REMOTE = 0
    MISSING_FROM_LOCAL = 1
    OUT_OF_DATE = 2
    UP_TO_DATE = 3

    def __init__(self, name, local_version, remote_version):
        self.name = name
        self.local_version = local_version
        self.remote_version = remote_version

    @property
    def local_version_name(self):
        return self.local_version if self.local_version else ""

    @property
    def remote_version_name(self):
        return self.remote_version.name if self.remote_version else ""

    @property
    def remote_version_created_at(self):
        if self.remote_version is None:
            return ""

        local_time = self.remote_version.created.replace(
            tzinfo=timezone.utc
        ).astimezone()
        return local_time.strftime("%x at %I:%M %p")

    @property
    def remote_version_author(self):
        return self.remote_version.user if self.remote_version else ""

    @property
    def state(self):
        if self.remote_version is None:
            return Suite.MISSING_FROM_REMOTE

        if self.local_version is None:
            return Suite.MISSING_FROM_LOCAL

        if self.remote_version.name != self.local_version:
            return Suite.OUT_OF_DATE

        return Suite.UP_TO_DATE

    @property
    def state_text(self):
        return {
            Suite.MISSING_FROM_LOCAL: "No local version",
            Suite.MISSING_FROM_REMOTE: "No remote version",
            Suite.OUT_OF_DATE: "Out of date",
            Suite.UP_TO_DATE: "Up to date",
        }[self.state]
