"""
Created on 17 Jul 2017

@author: giles.hall
"""
import os


class Utilities(object):
    """ General purpose utilities required in the Agent
    """

    def calculateCRC(self, s):
        """
        Calculate the CRC (hash code) for a given string we are calculating this
        ourselves rather than using a library element so that we can use the same
        algorithms on all platforms and languages
        """
        hashValue = 0
        for c in s:
            cAsInt = ord(c)
            if cAsInt <= 127:  # sensetalk has some bad character at the beginning

                # Sensetalk interprets CRLF as two characters whereas other languages
                # (Ruby, Python) interpret it as one
                if ord(c) == 10:
                    hashValue = ((31 * hashValue) + 13) % 33554432

                hashValue = ((31 * hashValue) + cAsInt) % 33554432

        return hashValue

    def strip_non_ascii(self, string):
        """ Returns the string without non ASCII characters"""
        stripped = (c for c in string if 0 < ord(c) < 127)
        return "".join(stripped)

    def fileNameFromPath(self, path):
        """ Get the file name from a path including a file name
        """
        head, tail = os.path.split(path)
        return str(head), str(tail) or str(os.path.basename(head))

    def toForwardSlash(self, fileName):
        """ Convert path seperator to forward slashes
        """
        pathElements = []
        head, tail = os.path.split(fileName)
        while len(head) > 0:
            pathElements.insert(0, tail)
            head, tail = os.path.split(head)
        pathElements.insert(0, tail)
        return "/".join(pathElements)
